"use client";

import React from "react";
import { AdvancedMarker } from "@vis.gl/react-google-maps";
import GoogleMap from "@/components/googleMap";
import { Box } from "@chakra-ui/react";
import { ILocation } from "../variables/location";
import Filters from "@/components/filters/Filters";
import { MultiSelectOption } from "@/components/fields/MultiSelect";

interface MultiMarkerMapProps {
  locations: ILocation[];
  users: MultiSelectOption[];
  ibcs: MultiSelectOption[];
}

const MultiMarkerMap = ({ locations, users, ibcs }: MultiMarkerMapProps) => {
  const getMarkerIcon = (color: string) => ({
    path: "M12 2C8.13 2 5 5.13 5 9c0 3.87 7 11 7 11s7-7.13 7-11c0-3.87-3.13-7-7-7z",
    fillColor: color,
    fillOpacity: 1,
    strokeColor: "black",
    strokeWeight: 1,
    scale: 2.1,
  });

  const today = new Date();
  const yesterday = new Date(today);
  yesterday.setDate(today.getDate() - 1);

  const yesterdayDate = yesterday.toISOString().split("T")[0];

  return (
    <Box my={20}>
      <Box pb={6}>
      <Filters users={users} ibcs={ibcs} showBatches={false} showExport={false} showSearch={false} defaultMax={yesterdayDate} />
      </Box>
      <GoogleMap
        defaultCenter={{
          lat: parseFloat(locations[0]?.latitude || "0"),
          lng: parseFloat(locations[0]?.longitude || "0"),
        }}
        defaultZoom={17}
      >
        {locations &&
          locations.map((location) => (
            <AdvancedMarker
              key={location.id}
              position={{
                lat: parseFloat(location.latitude),
                lng: parseFloat(location.longitude),
              }}
              clickable
              onClick={() =>
                alert(
                  `User ${location?.user?.first_name} is currently ${location.status}`
                )
              }
              title={`${location?.user?.first_name ?? ""} ${location?.user?.last_name ?? ""} (${location.status})`}
              // @ts-ignore
              icon={getMarkerIcon(
                location.status === "active" ? "green" : "red"
              )}
            />
          ))}
      </GoogleMap>
    </Box>
  );
};

export default MultiMarkerMap;
